///File : F2fVerbs.hpp
//------------------------------------------------------------------------------
/*
    This file is part of forbidden2forget.

    Forbidden2forget is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Forbidden2forget is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with forbidden2forget.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include <string>
#include <iostream>
#include <vector>
#if not defined TIXML_USE_TICPP
    #define TIXML_USE_TICPP
#endif
#include "ticpp/ticpp.h"
//------------------------------------------------------------------------------

#define NB_LEFT_PER_VERB 5

#if not defined F2F_VERBS_HPP
#define F2F_VERBS_HPP

class F2fVerbs
{
public:
    F2fVerbs();

    void Save() const;
    void LoadFromFile(std::string filename);
    void New(std::string originFilename, std::string newFilename, std::string userName);
    void SetPassword(std::string password);
    std::string GetFilename() const;
    void Clear();
    bool IsOk() const;
    bool IsPassword() const;
    bool IsProtected() const;
    bool IsCorrecting() const;
    bool IsFinish() const;


    void GetNewVerb();
    bool Correct(std::string bv, std::string pret, std::string pp);
    void TryPassword(std::string password);

    // Infos
    int GetTotalVerbsAtBegining() const;
    int GetTotalVerbs() const;
    int GetTotalLeft() const;
    std::string GetLevel() const;
    std::string GetPupileName() const;
    int GetWorkDuration() const;
    void AdToElapsedSeconds(int second);
    int GetErrorNumber() const;

    std::string GetCurrentFr() const;
    std::string GetCurrentBV() const;
    std::string GetCurrentPret() const;
    std::string GetCurrentPP() const;
    int GetCurrentNbLeft() const;

private:
    int hasard(int min, int max) const;
    bool isAbleToDeliverInfo()  const;

    ticpp::Element *PrepareInfo(const std::string &nom, const std::string &info) const;
    ticpp::Element *PrepareVerb(const int i) const;
    std::string intToString(int nb) const;
    int stringToInt(std::string nbStr) const;

    ticpp::Element *truc;

    bool m_isOk;
    struct v
    {
        std::vector<std::string> fr;
        std::vector<std::string> bv;
        std::vector<std::string> pret;
        std::vector<std::string> pp;
        std::vector<int> nbLeft;

        int idV;

        std::string filename, userName, password, level;
        int nbVerbsAtBegining, nbErrors;
        int elapsedSeconds;

        bool isProtected, isCorrecting;
    };

    v m_v;
};




#endif //F2F_VERBS_HPP
